==> nextcloud-9.0.53.tar.bz2: nextcloud/apps/encryption/l10n/et_EE.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Muuda taastevõtme parool",
    "Please repeat the recovery key password" : "Palun korda uut taastevõtme parooli",
    "Repeated recovery key password does not match the provided recovery key password" : "Lahtritesse sisestatud taastevõtme paroolid ei kattu",
    "Recovery key successfully enabled" : "Taastevõtme lubamine õnnestus",
    "Could not enable recovery key. Please check your recovery key password!" : "Ei suutnud lubada taastevõtit. Palun kontrolli oma taastevõtme parooli!",
    "Recovery key successfully disabled" : "Taastevõtme keelamine õnnestus",
    "Could not disable recovery key. Please check your recovery key password!" : "Ei suuda keelata taastevõtit. Palun kontrolli oma taastevõtme parooli!",
    "Missing parameters" : "Paramttrid puuduvad",
    "Please provide the old recovery password" : "Palun sisesta vana taastevõtme parool",
    "Please provide a new recovery password" : "Palun sisesta uus taastevõtme parool",
    "Please repeat the new recovery password" : "Palun korda uut taastevõtme parooli",
    "Password successfully changed." : "Parool edukalt vahetatud.",
    "Could not change the password. Maybe the old password was not correct." : "Ei suutnud vahetada parooli. Võib-olla on vana parool valesti sisestatud.",
    "Recovery Key disabled" : "Taastevõti on välja lülitatud",
    "Recovery Key enabled" : "Taastevõti on sisse lülitatud",
    "Could not update the private key password." : "Ei suutnud uuendada privaatse võtme parooli.",
    "The old password was not correct, please try again." : "Vana parool polnud õige, palun proovi uuesti.",
    "The current log-in password was not correct, please try again." : "Praeguse sisselogimise parool polnud õige, palun proovi uuesti.",
    "Private key password successfully updated." : "Privaatse võtme parool edukalt uuendatud.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Vigane Krüpteerimisrakendi privaatvõti . Palun uuenda oma privaatse võtme parool oma personaasete seadete all taastamaks ligipääsu oma krüpteeritud failidele.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Krüpteerimisrakend on lubatud, kuid võtmeid pole lähtestatud. Palun logi välja ning uuesti sisse.",
    "Bad Signature" : "Vigane allkiri",
    "Missing Signature" : "Allkiri puudub",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Sa ei saa seda faili dekrüpteerida, see on tõenäoliselt jagatud fail. Palun lase omanikul seda faili sinuga uuesti jagada.",
    "The share will expire on %s." : "Jagamine aegub %s.",
    "Cheers!" : "Terekest!",
    "Enable recovery key" : "Luba taastevõtme kasutamine",
    "Disable recovery key" : "Keela taastevõtme kasutamine",
    "Recovery key password" : "Taastevõtme parool",
    "Repeat recovery key password" : "Korda taastevõtme parooli",
    "Change recovery key password:" : "Muuda taastevõtme parooli:",
    "Old recovery key password" : "Vana taastevõtme parool",
    "New recovery key password" : "Uus taastevõtme parool",
    "Repeat new recovery key password" : "Korda uut taastevõtme parooli",
    "Change Password" : "Muuda parooli",
    "Nextcloud basic encryption module" : "Nextcloud peamine küpteerimismoodul",
    "Your private key password no longer matches your log-in password." : "Sinu provaatvõtme parool ei kattu enam sinu sisselogimise parooliga.",
    "Set your old private key password to your current log-in password:" : "Pane oma vana privaatvõtme parooliks oma praegune sisselogimise parool.",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Kui sa ei mäleta oma vana parooli, siis palu oma süsteemihalduril taastada ligipääs failidele.",
    "Old log-in password" : "Vana sisselogimise parool",
    "Current log-in password" : "Praegune sisselogimise parool",
    "Update Private Key Password" : "Uuenda privaatse võtme parooli",
    "Enable password recovery:" : "Luba parooli taaste:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Valiku lubamine võimaldab taastada ligipääsu krüpteeritud failidele kui parooli kaotuse puhul",
    "Enabled" : "Sisse lülitatud",
    "Disabled" : "Väljalülitatud"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/encryption/l10n/et_EE.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Muuda taastevõtme parool",
    "Please repeat the recovery key password" : "Palun korda uut taastevõtme parooli",
    "Repeated recovery key password does not match the provided recovery key password" : "Lahtritesse sisestatud taastevõtme paroolid ei kattu",
    "Recovery key successfully enabled" : "Taastevõtme lubamine õnnestus",
    "Could not enable recovery key. Please check your recovery key password!" : "Ei suutnud lubada taastevõtit. Palun kontrolli oma taastevõtme parooli!",
    "Recovery key successfully disabled" : "Taastevõtme keelamine õnnestus",
    "Could not disable recovery key. Please check your recovery key password!" : "Ei suuda keelata taastevõtit. Palun kontrolli oma taastevõtme parooli!",
    "Missing parameters" : "Paramttrid puuduvad",
    "Please provide the old recovery password" : "Palun sisesta vana taastevõtme parool",
    "Please provide a new recovery password" : "Palun sisesta uus taastevõtme parool",
    "Please repeat the new recovery password" : "Palun korda uut taastevõtme parooli",
    "Password successfully changed." : "Parool edukalt vahetatud.",
    "Could not change the password. Maybe the old password was not correct." : "Ei suutnud vahetada parooli. Võib-olla on vana parool valesti sisestatud.",
    "Recovery Key disabled" : "Taastevõti on välja lülitatud",
    "Recovery Key enabled" : "Taastevõti on sisse lülitatud",
    "Could not update the private key password." : "Ei suutnud uuendada privaatse võtme parooli.",
    "The old password was not correct, please try again." : "Vana parool polnud õige, palun proovi uuesti.",
    "The current log-in password was not correct, please try again." : "Praeguse sisselogimise parool polnud õige, palun proovi uuesti.",
    "Private key password successfully updated." : "Privaatse võtme parool edukalt uuendatud.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Vigane Krüpteerimisrakendi privaatvõti . Palun uuenda oma privaatse võtme parool oma personaasete seadete all taastamaks ligipääsu oma krüpteeritud failidele.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Krüpteerimisrakend on lubatud, kuid võtmeid pole lähtestatud. Palun logi välja ning uuesti sisse.",
    "Bad Signature" : "Vigane allkiri",
    "Missing Signature" : "Allkiri puudub",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Sa ei saa seda faili dekrüpteerida, see on tõenäoliselt jagatud fail. Palun lase omanikul seda faili sinuga uuesti jagada.",
    "The share will expire on %s." : "Jagamine aegub %s.",
    "Cheers!" : "Terekest!",
    "Enable recovery key" : "Luba taastevõtme kasutamine",
    "Disable recovery key" : "Keela taastevõtme kasutamine",
    "Recovery key password" : "Taastevõtme parool",
    "Repeat recovery key password" : "Korda taastevõtme parooli",
    "Change recovery key password:" : "Muuda taastevõtme parooli:",
    "Old recovery key password" : "Vana taastevõtme parool",
    "New recovery key password" : "Uus taastevõtme parool",
    "Repeat new recovery key password" : "Korda uut taastevõtme parooli",
    "Change Password" : "Muuda parooli",
    "basic encryption module" : "peamine küpteerimismoodul",
    "Your private key password no longer matches your log-in password." : "Sinu provaatvõtme parool ei kattu enam sinu sisselogimise parooliga.",
    "Set your old private key password to your current log-in password:" : "Pane oma vana privaatvõtme parooliks oma praegune sisselogimise parool.",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Kui sa ei mäleta oma vana parooli, siis palu oma süsteemihalduril taastada ligipääs failidele.",
    "Old log-in password" : "Vana sisselogimise parool",
    "Current log-in password" : "Praegune sisselogimise parool",
    "Update Private Key Password" : "Uuenda privaatse võtme parooli",
    "Enable password recovery:" : "Luba parooli taaste:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Valiku lubamine võimaldab taastada ligipääsu krüpteeritud failidele kui parooli kaotuse puhul",
    "Enabled" : "Sisse lülitatud",
    "Disabled" : "Väljalülitatud"
},
"nplurals=2; plural=(n != 1);");
